==> haskell-ansi-terminal-0.9.1-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ansi-terminal
version: 0.9.1
id: ansi-terminal-0.9.1-7greAUREMxf1pgDTp3Pb1X
key: ansi-terminal-0.9.1-7greAUREMxf1pgDTp3Pb1X
license: BSD-3-Clause
maintainer: Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>
author: Max Bolingbroke
homepage: https://github.com/feuerbach/ansi-terminal
synopsis: Simple ANSI terminal support, with Windows compatibility
description:
    ANSI terminal support for Haskell: allows cursor movement,
    screen clearing, color output, showing or hiding the
    cursor, and changing the title. Works on UNIX and Windows.
category: User Interfaces
abi: d7005a78dbf40209d2d2d6fab27299e1
exposed: True
exposed-modules:
    System.Console.ANSI System.Console.ANSI.Codes
    System.Console.ANSI.Types
hidden-modules: System.Console.ANSI.Unix
import-dirs: /usr/lib/ghc-8.6.5/site-local/ansi-terminal-0.9.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/ansi-terminal-0.9.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ansi-terminal-0.9.1
hs-libraries: HSansi-terminal-0.9.1-7greAUREMxf1pgDTp3Pb1X
depends:
    base-4.12.0.0 colour-2.3.5-KhGPW5qZVuqBSMjjUiJ91B
haddock-interfaces: /usr/share/doc/haskell-ansi-terminal/html/ansi-terminal.haddock
haddock-html: /usr/share/doc/haskell-ansi-terminal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ansi-terminal-0.9.1-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ansi-terminal
version: 0.9.1
id: ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj
key: ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj
license: BSD-3-Clause
maintainer: Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>
author: Max Bolingbroke
homepage: https://github.com/feuerbach/ansi-terminal
synopsis: Simple ANSI terminal support, with Windows compatibility
description:
    ANSI terminal support for Haskell: allows cursor movement,
    screen clearing, color output, showing or hiding the
    cursor, and changing the title. Works on UNIX and Windows.
category: User Interfaces
abi: 7f6286de6fe4567dc7fb387dbaca4073
exposed: True
exposed-modules:
    System.Console.ANSI System.Console.ANSI.Codes
    System.Console.ANSI.Types
hidden-modules: System.Console.ANSI.Unix
import-dirs: /usr/lib/ghc-8.6.5/site-local/ansi-terminal-0.9.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/ansi-terminal-0.9.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ansi-terminal-0.9.1
hs-libraries: HSansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj
depends:
    base-4.12.0.0 colour-2.3.5-y0xjV3ONUd40VuBtReEvC
haddock-interfaces: /usr/share/doc/haskell-ansi-terminal/html/ansi-terminal.haddock
haddock-html: /usr/share/doc/haskell-ansi-terminal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
